==> openwebbeans-1.2.8-source-release.zip: openwebbeans-1.2.8/webbeans-impl/src/test/java/org/apache/webbeans/test/unittests/specializes/SpecializationComponentTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.unittests.specializes;

import javax.enterprise.inject.spi.Bean;

import org.apache.webbeans.config.WebBeansContext;
import org.apache.webbeans.test.TestContext;
import org.apache.webbeans.test.component.specializes.AsynhrounousSpecalizesService;
import org.apache.webbeans.test.component.specializes.SpecializesServiceInjectorComponent;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class SpecializationComponentTest extends TestContext
{
    public SpecializationComponentTest()
    {
        super(SpecializationComponentTest.class.getName());
    }

    @Override
    @Before
    public void init()
    {
    }
    
    @Test
    public void testMockService()
    {
        clear();

        WebBeansContext.getInstance().getContextFactory().initRequestContext(null);

        Bean<AsynhrounousSpecalizesService> bean2 = defineManagedBean(AsynhrounousSpecalizesService.class);
        Bean<SpecializesServiceInjectorComponent> bean3 = defineManagedBean(SpecializesServiceInjectorComponent.class);
        
        AsynhrounousSpecalizesService instanceOther = getManager().getInstance(bean2);
        
        Assert.assertNotNull(instanceOther);
        
        SpecializesServiceInjectorComponent instance = getManager().getInstance(bean3);
    }
}

==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/unittests/specializes/SpecializationComponentTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.unittests.specializes;

import org.apache.webbeans.test.AbstractUnitTest;
import org.apache.webbeans.test.annotation.binding.Asynchronous;
import org.apache.webbeans.test.component.specializes.AsynhrounousSpecalizesService;
import org.apache.webbeans.test.component.specializes.SpecializesServiceInjectorComponent;
import org.junit.Assert;
import org.junit.Test;

import javax.enterprise.util.AnnotationLiteral;

public class SpecializationComponentTest extends AbstractUnitTest
{
    @Test
    public void testMockService()
    {
        startContainer(AsynhrounousSpecalizesService.class, SpecializesServiceInjectorComponent.class);
        
        AsynhrounousSpecalizesService instanceOther
                = getInstance(AsynhrounousSpecalizesService.class, new AnnotationLiteral<Asynchronous>() {});
        Assert.assertNotNull(instanceOther);

        SpecializesServiceInjectorComponent instance = getInstance(SpecializesServiceInjectorComponent.class);
        Assert.assertNotNull(instance);
    }
}
